==> scikit_digital_health-0.11.3-cp38-cp38-macosx_10_16_x86_64.whl: skdh/io/numpy_compressed.py <==
"""
Read from a numpy compressed file.

Lukas Adamowicz
Copyright (c) 2021. Pfizer Inc. All rights reserved.
"""
from numpy import load

from skdh.base import BaseProcess
from skdh.io.base import check_input_file


class ReadNumpyFile(BaseProcess):
    """
    Read a Numpy compressed file into memory. The file should have been
    created by `numpy.savez`. The data contained is read in
    unprocessed - ie acceleration is already assumed to be in units of
    'g' and time in units of seconds. No day windowing is performed. Expected
    keys are `time` and `accel`. If `fs` is present, it is used as well.

    Parameters
    ----------
    ext_error : {"warn", "raise", "skip"}, optional
        What to do if the file extension does not match the expected extension (.npz).
        Default is "warn". "raise" raises a ValueError. "skip" skips the file
        reading altogether and attempts to continue with the pipeline.
    """

    def __init__(self, ext_error="warn"):
        super(ReadNumpyFile, self).__init__(ext_error=ext_error)

        if ext_error.lower() in ["warn", "raise", "skip"]:
            self.ext_error = ext_error.lower()
        else:
            raise ValueError("`ext_error` must be one of 'raise', 'warn', 'skip'.")

    @check_input_file(".npz", check_size=True)
    def predict(self, file=None, **kwargs):
        """
        predict(file)

        Read the data from a numpy compressed file.

        Parameters
        ----------
        file : {str, Path}
            Path to the file to read. Must either be a string, or be able to be
            converted by `str(file)`.

        Returns
        -------
        data : dict
            Dictionary of the data contained in the file.

        Raises
        ------
        ValueError
            If the file name is not provided

        Notes
        -----
        The keys in `data` depend on which data the file contained. Potential keys are:

        - `accel`: acceleration [g]
        - `time`: timestamps [s]
        - `fs`: sampling frequency in Hz.
        """
        super().predict(expect_days=False, expect_wear=False, file=file, **kwargs)

        data = load(file)

        kwargs.update(
            {self._time: data["time"], self._acc: data["accel"], "file": file}
        )
        if "fs" in data:
            kwargs["fs"] = data["fs"][()]

        return (kwargs, None) if self._in_pipeline else kwargs

==> scikit_digital_health-0.11.5-cp38-cp38-macosx_10_16_x86_64.whl: skdh/io/numpy_compressed.py <==
"""
Read from a numpy compressed file.

Lukas Adamowicz
Copyright (c) 2021. Pfizer Inc. All rights reserved.
"""
from numpy import load as np_load

from skdh.base import BaseProcess
from skdh.io.base import check_input_file


class ReadNumpyFile(BaseProcess):
    """
    Read a Numpy compressed file into memory. The file should have been
    created by `numpy.savez`. The data contained is read in
    unprocessed - ie acceleration is already assumed to be in units of
    'g' and time in units of seconds. No day windowing is performed. Expected
    keys are `time` and `accel`. If `fs` is present, it is used as well.

    Parameters
    ----------
    allow_pickle : bool, optional
        Allow pickled objects in the NumPy file. Default is False, which is the safer option.
        For more information see :py:meth:`numpy.load`.
    ext_error : {"warn", "raise", "skip"}, optional
        What to do if the file extension does not match the expected extension (.npz).
        Default is "warn". "raise" raises a ValueError. "skip" skips the file
        reading altogether and attempts to continue with the pipeline.
    """

    def __init__(self, allow_pickle=False, ext_error="warn"):
        super(ReadNumpyFile, self).__init__(allow_pickle=allow_pickle, ext_error=ext_error)

        self.allow_pickle = allow_pickle

        if ext_error.lower() in ["warn", "raise", "skip"]:
            self.ext_error = ext_error.lower()
        else:
            raise ValueError("`ext_error` must be one of 'raise', 'warn', 'skip'.")

    @check_input_file(".npz", check_size=True)
    def predict(self, file=None, **kwargs):
        """
        predict(file)

        Read the data from a numpy compressed file.

        Parameters
        ----------
        file : {str, Path}
            Path to the file to read. Must either be a string, or be able to be
            converted by `str(file)`.

        Returns
        -------
        data : dict
            Dictionary of the data contained in the file.

        Raises
        ------
        ValueError
            If the file name is not provided

        Notes
        -----
        The keys in `data` depend on which data the file contained. Potential keys are:

        - `accel`: acceleration [g]
        - `time`: timestamps [s]
        - `fs`: sampling frequency in Hz.
        """
        super().predict(expect_days=False, expect_wear=False, file=file, **kwargs)

        with np_load(file, allow_pickle=self.allow_pickle) as data:
            kwargs.update(data)  # pull everything in
            # make sure that fs is saved properly
            if "fs" in data:
                kwargs["fs"] = data["fs"][()]

        # check that time and accel are in the correct names
        if self._time not in kwargs or self._acc not in kwargs:
            raise ValueError(f"Missing `{self._time}` or `{self._acc}` arrays in the file")

        # make sure we return the file
        kwargs.update({'file': file})

        return (kwargs, None) if self._in_pipeline else kwargs
